@@ -30,7 +30,7 @@ import pandas as pd
 from mitosheet.user import initialize_user
 from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.saved_analyses import register_analysis
-from mitosheet.errors import CreationError, EditError
+from mitosheet.errors import MitoError
 from mitosheet._version import __version__
 from mitosheet.column_headers import flatten_column_header
 
@@ -47,7 +47,6 @@ from mitosheet.api.graph.graph_utils import filter_df_to_safe_size
 
 # Make sure the user is initalized
 initialize_user()
-log('imported_mitosheet', check_mitosheet_install=True)
 
 # This function is only necessary for mitosheet3, as it is used
 # in jlab3 to find the extension. It is not used in jlab2
@@ -55,4 +54,4 @@ def _jupyter_labextension_paths():
     return [{
         "src": "labextension",
         "dest": 'mitosheet3'
-    }]
\ No newline at end of file
+    }]
