@@ -6,12 +6,15 @@ from mitosheet.user.db import set_user_field
 import sys
 from mitosheet.user import initialize_user
 from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY, UJ_USER_EMAIL
+from mitosheet.startup.startup_utils import create_startup_file, remove_startup_file
 
 def main():
     """
     Currently, the main usage of this function is:
     python -m mitosheet turnofflogging
     python -m mitosheet turnonlogging
+    python -m mitosheet turnoffdataframebutton
+    python -m mitosheet turnondataframebutton
 
     We also have 
     python -m mitosheet clearemail
@@ -34,6 +37,14 @@ def main():
             print("Clearing email")
             set_user_field(UJ_USER_EMAIL, '')
             print("Email cleared")
+        if sys.argv[-1] == 'turnoffdataframebutton':
+            print("Turning off the 'View in Mito' dataframe button")
+            remove_startup_file()
+            print("Turned off the 'View in Mito' dataframe button\nThe next time you launch Jupyter Lab, the button will no longer be visible")
+        if sys.argv[-1] == 'turnondataframebutton':
+            print("Turning on the 'View in Mito' dataframe button")
+            create_startup_file()
+            print("Turned on the 'View in Mito' dataframe button\nThe next time you launch Jupyter Lab, the button will be visible")
 
 
 if __name__ == '__main__':
