@@ -7,23 +7,25 @@
 """
 Contains handlers for the Mito API
 """
-from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
-from mitosheet.api.get_pivot_params import get_pivot_params
 from queue import Queue
 from threading import Thread
 
-from mitosheet.mito_analytics import log_event_processed
-from mitosheet.api.graph import get_graph
-from mitosheet.api.get_path_join import get_path_join
-from mitosheet.api.get_datafiles import get_datafiles
-from mitosheet.api.get_path_contents import get_path_contents
-from mitosheet.api.get_column_dtype import get_column_dtype
-from mitosheet.api.get_import_summary import get_import_summary
 from mitosheet.api.get_column_describe import get_column_describe
+from mitosheet.api.get_column_dtype import get_column_dtype
+from mitosheet.api.get_datafiles import get_datafiles
 from mitosheet.api.get_dateframe_as_csv import get_dataframe_as_csv
+from mitosheet.api.get_excel_file_metadata import get_excel_file_metadata
+from mitosheet.api.get_import_summary import get_import_summary
+from mitosheet.api.get_path_contents import get_path_contents
+from mitosheet.api.get_path_join import get_path_join
+from mitosheet.api.get_pivot_params import get_pivot_params
+from mitosheet.api.get_saved_analysis_description import \
+    get_saved_analysis_description
+from mitosheet.api.get_search_matches import get_search_matches
+from mitosheet.api.get_sheet_data import get_sheet_data
 from mitosheet.api.get_unique_value_counts import get_unique_value_counts
-from mitosheet.api.get_saved_analysis_description import get_saved_analysis_description
-
+from mitosheet.api.graph import get_graph
+from mitosheet.mito_analytics import log_event_processed
 
 # As the column summary statistics tab does three calls, we defaulted to this max
 MAX_QUEUED_API_CALLS = 3
@@ -62,8 +64,12 @@ class API():
 
         Because we are using a queue, only events that have not been started 
         being processed will get removed.
+
+        If the key 'priority' is in the event, then we handle it in the main
+        thread, as we don't want to drop the event. For example, lazy loading
+        data has priority!
         """        
-        if THREADED:
+        if THREADED and 'priority' not in event:
             if self.api_queue.full():
                 self.api_queue.get()
             self.api_queue.put(event)
@@ -126,6 +132,10 @@ def handle_api_event(send, event, steps_manager):
         result = get_excel_file_metadata(event, steps_manager)
     elif event['type'] == 'get_unique_value_counts':
         result = get_unique_value_counts(event, steps_manager)
+    elif event['type'] == 'get_search_matches':
+        result = get_search_matches(event, steps_manager)
+    elif event['type'] == 'get_cell_values':
+        result = get_sheet_data(event, steps_manager)
     else:
         raise Exception(f'Event: {event} is not a valid API call')
     
