@@ -73,8 +73,12 @@ def get_path_contents(event):
     return json.dumps({
         'path': path,
         'path_parts': get_path_parts(path),
-        'files': filenames,
-        'directories': dirnames
+        # For each element, record if it's a directory, and the time it was last modified
+        'elements': [
+            {'name': f, 'isDirectory': False, 'lastModified': os.path.getmtime(os.path.join(path, f))} for f in filenames
+        ] + [
+            {'name': d, 'isDirectory': True, 'lastModified': os.path.getmtime(os.path.join(path, d))} for d in dirnames
+        ]
     })
     
     
