@@ -36,7 +36,6 @@ def get_unique_value_counts(event, steps_manager):
         {},
         {},
         {'values': 'values', 'percents': 'percents', 'counts': 'counts'},
-        {'values': 'values', 'percents': 'percents', 'counts': 'counts'},
-        length_restriction=False
+        max_length=None
     ))
 
