@@ -92,7 +92,7 @@ def get_graph_title(x_axis_column_headers, y_axis_column_headers, filtered, grap
         graph_filter_label = GRAPH_FILTER_LABELS[graph_type] if filtered else None
 
     # Compile all of the column headers into one comma separated string
-    all_column_headers = (', ').join(x_axis_column_headers + y_axis_column_headers)
+    all_column_headers = (', ').join(str(s) for s in x_axis_column_headers + y_axis_column_headers)
     # Get the title of the graph based on the type of graph
     graph_title_label = GRAPH_TITLE_LABELS[graph_type] if special_title is None else special_title
     # Combine all of the non empty graph title components into one list
