@@ -35,7 +35,7 @@ class MitoError(Exception):
         self.to_fix = to_fix
         self.error_modal = error_modal
 
-def make_no_sheet_error(sheet_indexes: Set[str]):
+def make_no_sheet_error(sheet_indexes: Set[int]):
     """
     Helper function for creating a no_sheet_error.
 
