@@ -83,13 +83,21 @@ def anonymize_word(word):
     return valid_words[index_one] + valid_words[index_two] + valid_words[index_three]
 
 
-def anonymize_formula(formula):
+def anonymize_formula(formula, sheet_index, steps_manager=None):
     """
     Helper function that anonymizes formula to 
     make sure that no private data is included in it.
     """
+    if steps_manager is None:
+        return anonymize_word(formula)
+
     # We just input a random address, as we don't use it
-    _, _, dependencies = parse_formula(formula, 'A', throw_errors=False)
+    _, _, dependencies = parse_formula(
+        formula, 
+        'A', 
+        steps_manager.dfs[sheet_index].columns,
+        throw_errors=False
+    )
     
     for dependency in dependencies:
         formula = formula.replace(dependency, anonymize_word(dependency))
@@ -149,7 +157,7 @@ def get_installed_mitosheets_pip_show():
         return []
 
 
-def log(log_event, params=None, check_mitosheet_install=False):
+def log(log_event, params=None, steps_manager=None):
     """
     Helper function that logs an event with the given parameters. However,
     this function is also responsible for making sure _zero_ private data
@@ -158,9 +166,6 @@ def log(log_event, params=None, check_mitosheet_install=False):
     To accomplish this, we anonymize all data. To do so, we hash this data
     with a private secret that only the user has, making it impossible
     for us to brute force it.
-
-    NOTE: check_mitosheet_install can be an expensive operation for some
-    users, so we should try and minimize where / how we use it!
     """
     if not telemetry_turned_on():
         return
@@ -174,21 +179,11 @@ def log(log_event, params=None, check_mitosheet_install=False):
         'version_jupyterlab': get_jupyterlab_version(),
         'version_mito': __version__ 
     }
-    
-    if check_mitosheet_install:
-        pip_shows = get_installed_mitosheets_pip_show()
-        jupyter_labextension_list = get_jupyter_labextension_list()
-    else:
-        pip_shows = []
-        jupyter_labextension_list = []
+
     
     params = dict(
         **params,
-        **python_properties,
-        **{
-            'pip_shows': pip_shows,
-            'jupyter_labextension_list': jupyter_labextension_list
-        }
+        **python_properties
     )
 
     # Private params are where we _make sure_ that no private
@@ -198,7 +193,10 @@ def log(log_event, params=None, check_mitosheet_install=False):
     try:
         for key, value in params.items():
             # We take any of the items that contain private user data, and we anonymize them
-            if ('column_header' in key \
+            if 'rows' in key or 'columns' in key or 'selected_column_ids' in key:
+                # We anonymize all of the column headers in any list
+                private_params[key] = [anonymize_word(v) for v in value]
+            elif ('column_header' in key \
                 or 'column_id' in key \
                 or 'df_name' in key \
                 or 'dataframe_name' in key \
@@ -208,13 +206,10 @@ def log(log_event, params=None, check_mitosheet_install=False):
                 private_params[key] = anonymize_word(value)
             elif 'formula' in key:
                 # We make sure to remove any private references from a formula
-                private_params[key] = anonymize_formula(value)
+                private_params[key] = anonymize_formula(value, params['params_sheet_index'], steps_manager)
             elif 'file_names' in key:
                 # Just count the number of files, instead of keeping their names
                 private_params[key] = len(value)
-            elif 'rows' in key or 'columns' in key or 'selected_column_ids' in key:
-                # We anonymize all of the column headers in any list
-                private_params[key] = [anonymize_word(v) for v in value]
             elif 'values' in key:
                 # for pivot params, we anonymize the column headers
                 # and keep the agg functions
@@ -246,6 +241,13 @@ def log(log_event, params=None, check_mitosheet_install=False):
         # We log if we fail to build the private logs, so that we 
         # know that we have some issues here
         private_params['failed_building'] = True
+        try:
+            # Try and log a bit more about the error so we know why it failed
+            recent_traceback = get_recent_traceback_as_list()
+            private_params['error_traceback'] = recent_traceback
+            private_params['error_traceback_last_line'] = recent_traceback[-1] 
+        except:
+            pass
 
     # NOTE: we do not log anything when tests are running
     if not is_running_test():
@@ -404,7 +406,8 @@ def log_event_processed(event, steps_manager, failed=False, edit_error=None):
                 **event_properties,
                 **steps_manager_properties,
                 **error_properties
-            )
+            ),
+            steps_manager=steps_manager
         )
     except:
         # We don't want logging to ever brick the application, so if the logging fails
