@@ -12,7 +12,7 @@ require no user input.
 Which pre-process step, and the version of it that is used 
 """
 
-from typing import List
+from typing import List, Type
 
 from mitosheet.preprocessing.preprocess_step_performer import PreprocessStepPerformer
 from mitosheet.preprocessing.preprocess_read_file_paths import ReadFilePathsPreprocessStepPerformer
@@ -22,7 +22,7 @@ from mitosheet.preprocessing.preprocess_copy import CopyPreprocessStepPerformer
 
 # NOTE: these should be in the order you want to apply them to the arguments,
 # as they are run in a linear order
-PREPROCESS_STEP_PERFORMERS: List[PreprocessStepPerformer] = [
+PREPROCESS_STEP_PERFORMERS: List[Type[PreprocessStepPerformer]] = [
    # First, we make sure all the args are the right type
    CheckArgsTypePreprocessStepPerformer,
    # Then, we copy the args to make sure we don't change them accidently
