@@ -4,7 +4,7 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 from copy import deepcopy
-from typing import Any, Dict, List, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 import pandas as pd
 from mitosheet.preprocessing.preprocess_step_performer import \
@@ -26,7 +26,7 @@ class CopyPreprocessStepPerformer(PreprocessStepPerformer):
         return 'copy'
 
     @classmethod
-    def execute(cls, args: List[Any]) -> Tuple[List[Any], Dict[str, Any]]:
+    def execute(cls, args: List[Any]) -> Tuple[List[Any], Optional[Dict[str, Any]]]:
         
         new_args = []
         for arg in args:
@@ -40,5 +40,5 @@ class CopyPreprocessStepPerformer(PreprocessStepPerformer):
         return new_args, None
 
     @classmethod
-    def transpile(cls, steps_manager, execution_data: Dict[str, Any]) -> List[str]:
+    def transpile(cls, steps_manager, execution_data: Optional[Dict[str, Any]]) -> List[str]:
         return []
