@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 
-from typing import Any, Dict, List, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 import pandas as pd
 from mitosheet.errors import get_recent_traceback_as_list
@@ -34,9 +34,9 @@ class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
 
     @classmethod
     def execute(cls, args: List[Any]) -> Tuple[List[Any], Dict[str, Any]]:
-        df_args = []
-        delimeters = []
-        encodings = []
+        df_args: List[pd.DataFrame] = []
+        delimeters: List[Optional[str]] = []
+        encodings: List[Optional[str]] = []
         for arg in args:
             if isinstance(arg, pd.DataFrame):
                 df_args.append(arg)
@@ -71,7 +71,7 @@ class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
         }
 
     @classmethod
-    def transpile(cls, steps_manager, execution_data: Dict[str, Any]) -> List[str]:
+    def transpile(cls, steps_manager, execution_data: Optional[Dict[str, Any]]) -> List[str]:
         """
         Transpiles the reading in of passed file paths to dataframe names, 
         with a simple pd.read_csv call.
@@ -88,8 +88,8 @@ class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
         # will cause only variable to exist.
         df_names = get_valid_dataframe_names([], str_args)
 
-        delimeters = execution_data['delimeters']
-        encodings = execution_data['encodings']
+        delimeters = execution_data['delimeters'] if execution_data is not None else [None for _ in range(len(df_names))]
+        encodings = execution_data['encodings'] if execution_data is not None else [None for _ in range(len(df_names))]
 
         num_strs = 0
         for arg_index, arg in enumerate(steps_manager.original_args):
