@@ -1,16 +1,18 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 from typing import Any, Dict, List
+
 from mitosheet.saved_analyses.step_upgraders.utils_column_header_to_column_id import \
     replace_headers_with_id
 from mitosheet.saved_analyses.step_upgraders.utils_rename_column_headers import \
     BULK_OLD_RENAME_STEP
 
 
-def upgrade_group_1_to_pivot_2(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+def upgrade_group_1_to_pivot_2(step: Dict[str, Any], later_steps: List[Dict[str, Any]]):
     """
     Upgrades from a group 1 step to a pivot 2 step, simply
     by changing the names of the params.
@@ -43,7 +45,7 @@ def upgrade_group_1_to_pivot_2(step: Dict[str, Any], later_steps: List[Dict[str,
     }] + later_steps
 
 
-def upgrade_pivot_2_to_pivot_3(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+def upgrade_pivot_2_to_pivot_3(step: Dict[str, Any], later_steps: List[Dict[str, Any]]):
     """
     Upgrades from a pivot 2 step to a pivot 3 step, which simple
     changes the formats of the values key to be a list rather than
@@ -79,7 +81,7 @@ def upgrade_pivot_2_to_pivot_3(step: Dict[str, Any], later_steps: List[Dict[str,
     }] + later_steps
 
 
-def upgrade_pivot_3_to_4(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+def upgrade_pivot_3_to_4(step: Dict[str, Any], later_steps: List[Dict[str, Any]]):
     """
     Moves to using column id instead of column header.
 
@@ -119,7 +121,7 @@ def upgrade_pivot_3_to_4(step: Dict[str, Any], later_steps: List[Dict[str, Any]]
     }] + later_steps
 
 
-def upgrade_pivot_4_to_5_and_rename(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
+def upgrade_pivot_4_to_5_and_rename(step: Dict[str, Any], later_steps: List[Dict[str, Any]]):
     """
     Adds a rename step after pivot 4, as in the move from pivot 4 -> 5
     we got rid of the column headers that we used. Also makes sure that
@@ -166,44 +168,3 @@ def upgrade_pivot_4_to_5_and_rename(step: Dict[str, Any], later_steps: List[Dict
         BULK_OLD_RENAME_STEP
     ] + later_steps
 
-
-def upgrade_pivot_5_to_6(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
-    """
-    When moving from pivot 5 to pivot 6, we got rid of the flattening that
-    happened with column headers. As such, we add a parameter to the pivot
-    step to tell it to flatten the headers.
-
-    Old format: [
-        {
-            "step_version": 5, 
-            "step_type": "pivot", 
-            "params": {
-                sheet_index: 0,
-                pivot_rows_column_ids: List[_id_],
-                pivot_columns_column_ids: List[_id_],
-                values_column_ids_map: Dict[_id_, List[str]],
-                destination_sheet_index: 1,
-            }
-        },
-    ]
-
-    New format: [
-        {
-            "step_version": 6, 
-            "step_type": "pivot", 
-            "params": {
-                sheet_index: 0,
-                pivot_rows_column_ids: List[_id_],
-                pivot_columns_column_ids: List[_id_],
-                values_column_ids_map: Dict[_id_, List[str]],
-                destination_sheet_index: 1,
-                flatten_column_headers: True
-            }
-        },
-    ]
-    """
-    step['step_version'] = 6
-    step['params']['flatten_column_headers'] = True
-    
-    return [step] + later_steps
-
