@@ -24,8 +24,8 @@ from mitosheet.saved_analyses.step_upgraders.add_column import \
     upgrade_add_column_1_to_add_column_2
 from mitosheet.saved_analyses.step_upgraders.change_column_dtype import \
     upgrade_change_column_dtype_1_to_2
-from mitosheet.saved_analyses.step_upgraders.delete_column import \
-    upgrade_delete_column_1_to_2
+from mitosheet.saved_analyses.step_upgraders.delete_column import (
+    upgrade_delete_column_1_to_2, upgrade_delete_column_2_to_3)
 from mitosheet.saved_analyses.step_upgraders.filter import (
     update_filter_column_1_to_filter_column_2, upgrade_filter_column_2_to_3)
 from mitosheet.saved_analyses.step_upgraders.merge import (
@@ -86,7 +86,8 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
         1: upgrade_change_column_dtype_1_to_2
     },
     'delete_column': {
-        1: upgrade_delete_column_1_to_2
+        1: upgrade_delete_column_1_to_2,
+        2: upgrade_delete_column_2_to_3
     },
     'filter_column': {
         2: upgrade_filter_column_2_to_3
