@@ -14,6 +14,7 @@ in more detail in docs/README.md.
 
 NOTE: This file is alphabetical order!
 """
+from typing import Tuple
 from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES
 import pandas as pd
 import functools
@@ -25,7 +26,7 @@ from mitosheet.sheet_functions.sheet_function_utils import try_extend_series_to_
 @handle_sheet_function_errors
 @filter_nans
 @convert_args_to_series_type(BOOLEAN_SERIES, 'skip', ('default', True))
-def AND(*argv) -> pd.Series:
+def AND(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "AND",
@@ -139,7 +140,7 @@ def IF(condition: pd.Series, true_series, false_series) -> pd.Series:
 @handle_sheet_function_errors
 @filter_nans
 @convert_args_to_series_type(BOOLEAN_SERIES, 'skip', ('default', True))
-def OR(*argv) -> pd.Series:
+def OR(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "OR",
