@@ -15,6 +15,7 @@ in more detail in docs/README.md.
 NOTE: This file is alphabetical order!
 """
 import functools
+from typing import Tuple
 import pandas as pd
 import numpy as np
 
@@ -52,7 +53,7 @@ def ABS(series: pd.Series):
 @handle_sheet_function_errors
 @filter_nans
 @convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', np.NaN))
-def AVG(*argv) -> pd.Series:
+def AVG(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "AVG",
@@ -157,7 +158,7 @@ def KURT(series) -> pd.Series:
 @filter_nans
 # NOTE: we set the default to -inf, so that we ignore values that fail to convert
 @convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', float("-inf")))
-def MAX(*argv) -> pd.Series:
+def MAX(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "MAX",
@@ -187,7 +188,7 @@ def MAX(*argv) -> pd.Series:
 @filter_nans
 # NOTE: we set the default to inf, so that we ignore values that fail to convert
 @convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', float("inf")))
-def MIN(*argv) -> pd.Series:
+def MIN(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "MIN",
@@ -216,7 +217,7 @@ def MIN(*argv) -> pd.Series:
 @handle_sheet_function_errors
 @filter_nans
 @convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', 1))
-def MULTIPLY(*argv) -> pd.Series:
+def MULTIPLY(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "MULTIPLY",
@@ -366,7 +367,7 @@ def SKEW(series) -> pd.Series:
 @handle_sheet_function_errors
 @filter_nans
 @convert_args_to_series_type(NUMBER_SERIES, 'skip', ('default', 0))
-def SUM(*argv) -> pd.Series:
+def SUM(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "SUM",
