@@ -13,6 +13,7 @@ in more detail in docs/README.md.
 NOTE: This file is alphabetical order!
 """
 import functools
+from typing import Tuple
 from mitosheet.sheet_functions.types.utils import NUMBER_SERIES, STRING_SERIES
 import pandas as pd
 import numpy as np
@@ -54,7 +55,7 @@ def CLEAN(series) -> pd.Series:
 @handle_sheet_function_errors
 @filter_nans
 @convert_args_to_series_type(STRING_SERIES, 'skip', ('default', ''))
-def CONCAT(*argv) -> pd.Series:
+def CONCAT(*argv: pd.Series) -> pd.Series:
     """
     {
         "function": "CONCAT",
