@@ -9,7 +9,7 @@ Decorators for sheet functions, that enable the sheet functions
 to make sure the inputs they are getting are the inputs they want
 """
 from mitosheet.sheet_functions.sheet_function_utils import is_series_of_constant
-from typing import Union, Tuple
+from typing import Any, Union, Tuple
 import pandas as pd
 from functools import wraps, partial
 
@@ -152,7 +152,7 @@ def filter_nans(sheet_function):
 
 def fill_nans(
         arg_index: int,
-        new_value: any,
+        new_value: Any,
         optional=False
     ):
     """
