@@ -12,7 +12,7 @@ from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_mito_type
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_mito_type, get_datetime_format
 
 def to_datetime_series(
         unknown_object,
@@ -36,6 +36,18 @@ def to_datetime_series(
         return None
     elif from_type == STRING_SERIES:
         # TODO: improve this to work element wise!
-        return pd.to_datetime(unknown_object)
+        datetime_format = get_datetime_format(unknown_object)
+        if datetime_format is not None:
+            return pd.to_datetime(
+                unknown_object,
+                format=datetime_format,
+                errors='coerce'
+            )
+        else:
+            return pd.to_datetime(
+                unknown_object,
+                infer_datetime_format=True,
+                errors='coerce'
+            )
     else:
         return None
\ No newline at end of file
