@@ -124,7 +124,7 @@ def get_mito_type(obj):
     return None
 
 
-def get_nan_indexes_metadata(*argv) -> Tuple[pd.Index, pd.Index, pd.Index]: 
+def get_nan_indexes_metadata(*argv) -> Tuple[pd.Index, pd.Index]: 
     """
     Given a list of series, this function returns data that is helpful
     in figuring out which of the rows of these series have a NaN in them.
