@@ -9,7 +9,7 @@ See mito/mitosheet/steps/README.md for more information about
 how to add a step!
 """
 
-from typing import Dict, List
+from typing import Dict, List, Type
 from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.pivot import PivotStepPerformer
@@ -29,8 +29,9 @@ from mitosheet.step_performers.dataframe_steps.dataframe_duplicate import Datafr
 from mitosheet.step_performers.dataframe_steps.dataframe_rename import DataframeRenameStepPerformer
 from mitosheet.step_performers.bulk_old_rename.bulk_old_rename import BulkOldRenameStepPerformer
 
-# All steps must be listed in this variable.
-STEP_PERFORMERS: List[StepPerformer] = [
+# All steps must be listed in this variable. Note the Type annotation allows for
+# subtypes of the step performer to be passed
+STEP_PERFORMERS: List[Type[StepPerformer]] = [
     PivotStepPerformer,
     ReorderColumnStepPerformer,
     FilterStepPerformer,
@@ -51,13 +52,13 @@ STEP_PERFORMERS: List[StepPerformer] = [
 ]
 
 # A helpful mapping for looking up steps based on the incoming events
-EVENT_TYPE_TO_STEP_PERFORMER: Dict[str, StepPerformer] = {
+EVENT_TYPE_TO_STEP_PERFORMER: Dict[str, Type[StepPerformer]] = {
     step_performer.step_event_type(): step_performer
     for step_performer in STEP_PERFORMERS
 }
 
 # We also build a useful lookup mapping for the step type to step object
-STEP_TYPE_TO_STEP_PERFORMER: Dict[str, StepPerformer] = {
+STEP_TYPE_TO_STEP_PERFORMER: Dict[str, Type[StepPerformer]] = {
     step_performer.step_type(): step_performer
     for step_performer in STEP_PERFORMERS
 }
