@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.errors import make_column_exists_error, make_no_sheet_error
 from mitosheet.sheet_functions.types.utils import NUMBER_SERIES
@@ -40,18 +40,18 @@ class AddColumnStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
         column_header: str,
         column_header_index: int,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
             
         # if the sheet doesn't exist, throw an error
         if not prev_state.does_sheet_index_exist_within_state(sheet_index):
-            raise make_no_sheet_error(sheet_index)
+            raise make_no_sheet_error({sheet_index})
 
         if column_header in prev_state.dfs[sheet_index].keys():
             raise make_column_exists_error(column_header)
@@ -80,7 +80,7 @@ class AddColumnStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -89,12 +89,13 @@ class AddColumnStepPerformer(StepPerformer):
         column_header: str,
         column_header_index: int
     ) -> List[str]:
+        column_header_index = execution_data["column_header_index"] if execution_data is not None else column_header_index
         return [
-            f'{post_state.df_names[sheet_index]}.insert({execution_data["column_header_index"]}, \'{column_header}\', 0)'
+            f'{post_state.df_names[sheet_index]}.insert({column_header_index}, \'{column_header}\', 0)'
         ]
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_header: str,
