@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 import pandas as pd
 from mitosheet.errors import get_recent_traceback, make_invalid_column_type_change_error
@@ -61,7 +61,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
@@ -69,7 +69,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         old_dtype: str,
         new_dtype: str,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # Create the post state
         post_state = copy(prev_state)
 
@@ -216,7 +216,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -337,7 +337,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         return code
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
