@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.errors import make_column_exists_error
 from mitosheet.parser import safe_replace
@@ -42,14 +42,14 @@ class RenameColumnStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
         column_id: str,
         new_column_header: str,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         if new_column_header in prev_state.dfs[sheet_index].keys():
             raise make_column_exists_error(new_column_header)
 
@@ -57,7 +57,7 @@ class RenameColumnStepPerformer(StepPerformer):
         # a mistake and not something they meant to do... so we just don't make any edits
         # and don't throw an error
         if new_column_header == '':
-            return None
+            return prev_state, None
 
         # Create a new post state for this step
         post_state = deepcopy(prev_state)
@@ -72,7 +72,7 @@ class RenameColumnStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -98,7 +98,7 @@ class RenameColumnStepPerformer(StepPerformer):
         return [f'{df_name}.rename(columns={rename_dict}, inplace=True)']
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
