@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -49,14 +49,14 @@ class ReorderColumnStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
         column_id: str,
         new_column_index: int,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
 
         column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
@@ -75,7 +75,7 @@ class ReorderColumnStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -101,7 +101,7 @@ class ReorderColumnStepPerformer(StepPerformer):
         return [columns_list_line, insert_line, apply_reorder_line]
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
