@@ -8,7 +8,7 @@ import pandas as pd
 
 from copy import deepcopy
 from mitosheet.step_performers.step_performer import StepPerformer
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 from mitosheet.state import State
 from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.topological_sort import creates_circularity, subgraph_from_starting_column_header, topological_sort_columns
@@ -71,7 +71,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
@@ -79,7 +79,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         old_formula: str,
         new_formula: str,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
         # First, we check the column_metatype, and make sure it's a formula
@@ -88,7 +88,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
 
         # If nothings changed, there's no work to do
         if (old_formula == new_formula):
-            return
+            return prev_state, None
 
         column_headers = prev_state.dfs[sheet_index].keys()
 
@@ -155,7 +155,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -171,7 +171,7 @@ class SetColumnFormulaStepPerformer(StepPerformer):
         return transpile_dependant_columns(post_state, sheet_index, column_id)
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
@@ -350,7 +350,7 @@ def refresh_dependant_columns(post_state: State, df: pd.DataFrame, sheet_index:
             # If we have a column header that does not exist in the formula, we may
             # throw a name error, in which case we alert the user
             column_header = str(e).split('\'')[1]
-            raise make_no_column_error([column_header])
+            raise make_no_column_error({column_header})
 
 
 def transpile_dependant_columns(
