@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
@@ -42,17 +42,17 @@ class DataframeRenameStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
         old_dataframe_name: str,
         new_dataframe_name: str,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # Bail early, if there is no change
         if old_dataframe_name == new_dataframe_name:
-            return
+            return prev_state, None
 
         # Create a new step and save the parameters
         post_state = copy(prev_state)
@@ -62,7 +62,7 @@ class DataframeRenameStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -76,7 +76,7 @@ class DataframeRenameStepPerformer(StepPerformer):
         return [f'{post_state.df_names[sheet_index]} = {old_dataframe_name}']
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         old_dataframe_name: str,
