@@ -9,7 +9,7 @@ import functools
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.state import State
 from numbers import Number
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 import pandas as pd
 from datetime import date
 
@@ -122,7 +122,7 @@ class FilterStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
@@ -130,7 +130,7 @@ class FilterStepPerformer(StepPerformer):
         operator: str,
         filters,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
 
         # Get the correct column_header
         column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
@@ -153,7 +153,7 @@ class FilterStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -200,7 +200,7 @@ class FilterStepPerformer(StepPerformer):
             ]
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
