@@ -4,16 +4,11 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 
-import csv
-from os.path import normpath, basename
-from mitosheet.utils import get_valid_dataframe_name, get_valid_dataframe_names
-import os
+from mitosheet.utils import get_valid_dataframe_name
 from copy import copy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
-import chardet
 import pandas as pd
-from mitosheet.errors import make_is_directory_error
 from mitosheet.state import DATAFRAME_SOURCE_IMPORTED, State
 from mitosheet.step_performers.step_performer import StepPerformer
 
@@ -45,7 +40,7 @@ class ExcelImportStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         file_name: str,
@@ -53,7 +48,7 @@ class ExcelImportStepPerformer(StepPerformer):
         has_headers: bool,
         skiprows: int,
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # Create a new step
         post_state = copy(prev_state)
 
@@ -79,7 +74,7 @@ class ExcelImportStepPerformer(StepPerformer):
 
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -118,7 +113,7 @@ class ExcelImportStepPerformer(StepPerformer):
         ] + df_definitions
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         file_name: str,
         sheet_names: List[str],
