@@ -6,7 +6,7 @@
 
 
 from copy import copy
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 from mitosheet.errors import make_incompatible_merge_key_error
 from mitosheet.sheet_functions.types.utils import get_mito_type
 from mitosheet.state import DATAFRAME_SOURCE_MERGED, State
@@ -40,7 +40,7 @@ class MergeStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         how: str,
@@ -51,7 +51,7 @@ class MergeStepPerformer(StepPerformer):
         merge_key_column_id_two: str,
         selected_column_ids_two: List[str],
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
 
     
         merge_key_one = prev_state.column_ids.get_column_header_by_id(sheet_index_one, merge_key_column_id_one)
@@ -81,7 +81,7 @@ class MergeStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -148,7 +148,7 @@ class MergeStepPerformer(StepPerformer):
         return merge_code
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         how: str,
         sheet_index_one: int,
