@@ -7,12 +7,11 @@
 
 from copy import copy
 from mitosheet.column_headers import flatten_column_header
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 import pandas as pd
 from mitosheet.errors import (make_invalid_aggregation_error,
-                              make_invalid_pivot_error, make_no_column_error,
-                              make_no_sheet_error)
+                              make_invalid_pivot_error, make_no_column_error)
 from mitosheet.state import DATAFRAME_SOURCE_PIVOTED, State
 from mitosheet.step_performers.step_performer import StepPerformer
 from pandas.core.base import DataError
@@ -71,14 +70,16 @@ class PivotStepPerformer(StepPerformer):
 
         # Filter out any duplicate aggregation functions
         for column_id, aggregation_function_names in params['values_column_ids_map'].items():
-            seen = set()
-            aggregation_function_names = [x for x in aggregation_function_names if not (x in seen or seen.add(x))]
-            params['values_column_ids_map'][column_id] = aggregation_function_names
+            new_aggregation_function_names = []
+            for i in aggregation_function_names:
+                if i not in new_aggregation_function_names:
+                    new_aggregation_function_names.append(i)
+            params['values_column_ids_map'][column_id] = new_aggregation_function_names
 
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
@@ -88,11 +89,7 @@ class PivotStepPerformer(StepPerformer):
         destination_sheet_index: int=None,
         use_deprecated_id_algorithm: bool=False,
         **params
-    ) -> State:
-
-        # if the sheets don't exist, throw an error
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index):
-            raise make_no_sheet_error(sheet_index)
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
 
         pivot_rows = prev_state.column_ids.get_column_headers_by_ids(sheet_index, pivot_rows_column_ids)
         pivot_columns = prev_state.column_ids.get_column_headers_by_ids(sheet_index, pivot_columns_column_ids)
@@ -139,7 +136,7 @@ class PivotStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -194,7 +191,7 @@ class PivotStepPerformer(StepPerformer):
         return transpiled_code
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index,
         pivot_rows_column_ids,
