@@ -5,7 +5,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import numpy as np
 from mitosheet.errors import make_cast_value_to_type_error, make_no_column_error
@@ -61,7 +61,7 @@ class SetCellValueStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
@@ -70,13 +70,13 @@ class SetCellValueStepPerformer(StepPerformer):
         old_value: str,
         new_value: Union[str, None],
         **params
-    ) -> State:
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         if column_id not in prev_state.column_metatype[sheet_index]:
-            raise make_no_column_error([column_id], error_modal=False)
+            raise make_no_column_error({column_id}, error_modal=False)
 
         # If nothings changed, there's no work to do
         if old_value == new_value:
-            return None
+            return prev_state, None
 
         post_state = deepcopy(prev_state)
 
@@ -102,7 +102,7 @@ class SetCellValueStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -113,7 +113,7 @@ class SetCellValueStepPerformer(StepPerformer):
         old_value: str,
         new_value: Union[str, None],
     ) -> List[str]:
-        code = []
+        code: List[str] = []
 
         # If nothings changed, we don't write any code
         if old_value == new_value:
@@ -143,7 +143,7 @@ class SetCellValueStepPerformer(StepPerformer):
 
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
@@ -168,7 +168,7 @@ def cast_value_to_type(value: Union[str, None], mito_series_type: str):
     series that it is going to be added to. 
     """
     # If the user it trying to make the value None, let them.
-    if is_none_type(value):
+    if is_none_type(value) or value is None:
         return None
 
     try:
