@@ -5,11 +5,9 @@
 # Distributed under the terms of the Modified BSD License.
 from copy import deepcopy
 from mitosheet.state import State
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.errors import (
-    make_no_sheet_error,
-    make_no_column_error,
     make_invalid_sort_error
 )
 
@@ -44,14 +42,14 @@ class SortStepPerformer(StepPerformer):
         return params
 
     @classmethod
-    def execute(
+    def execute( # type: ignore
         cls,
         prev_state: State,
         sheet_index: int,
         column_id: str,
         sort_direction: str,
         **params
-    ):
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         """
         Returns the new new post state after sorting the sheet
         at `sheet_index` by the passed `column_id` in the given
@@ -76,7 +74,7 @@ class SortStepPerformer(StepPerformer):
         return post_state, None
 
     @classmethod
-    def transpile(
+    def transpile( # type: ignore
         cls,
         prev_state: State,
         post_state: State,
@@ -94,7 +92,7 @@ class SortStepPerformer(StepPerformer):
         ]
 
     @classmethod
-    def describe(
+    def describe( # type: ignore
         cls,
         sheet_index: int,
         column_id: str,
