@@ -7,7 +7,7 @@ import json
 import uuid 
 from copy import copy, deepcopy
 import pandas as pd
-from typing import List, Tuple
+from typing import List, Set, Tuple
 
 from mitosheet.step_performers.import_steps.simple_import import SimpleImportStepPerformer
 from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
@@ -26,7 +26,7 @@ def get_step_indexes_to_skip(step_list: List[Step]):
     Given a list of steps, will collect all of the steps
     from this list that should be skipped.
     """
-    step_indexes_to_skip = set()
+    step_indexes_to_skip: Set[int] = set()
 
     for step_index, step in enumerate(step_list):
         step_indexes_to_skip = step_indexes_to_skip.union(
@@ -208,7 +208,8 @@ class StepsManager():
             self.curr_step.column_spreadsheet_code,
             self.curr_step.column_filters,
             self.curr_step.column_type,
-            self.curr_step.column_ids
+            self.curr_step.column_ids,
+            
         )
 
     @property
@@ -315,7 +316,7 @@ class StepsManager():
             # If we are removing steps, then we figure out what skipped steps 
             # we are losing, and run from right before where we are no longer
             # skipped steps
-            no_longer_skipped_indexes = set()
+            no_longer_skipped_indexes: Set[int] = set()
             for step_index, removed_step in enumerate(self.steps[len(new_steps):]):
                 previous_steps = self.steps[:len(new_steps) + step_index]
                 no_longer_skipped_indexes = no_longer_skipped_indexes.union(
@@ -328,7 +329,7 @@ class StepsManager():
             # we're adding, and run from right before the oldest new skipped step
 
             # Collect anything that is newly skipped
-            newly_skipped_indexes = set()
+            newly_skipped_indexes: Set[int] = set()
             for step_index, new_step in enumerate(new_steps[len(self.steps):]):
                 previous_steps = new_steps[:len(self.steps) + step_index]
                 newly_skipped_indexes = newly_skipped_indexes.union(
