@@ -4,7 +4,7 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 
-from mitosheet.sheet_functions.types.utils import get_mito_type
+from mitosheet.sheet_functions.types.utils import NUMBER_SERIES, STRING_SERIES, get_mito_type
 import pandas as pd
 import pytest
 import json
@@ -12,11 +12,11 @@ import json
 from mitosheet.tests.test_utils import create_mito_wrapper
 
 COLUMN_FILTER_TYPE_TESTS = [
-    ('int_column', 'number_series'),
-    ('float_column', 'number_series'),
-    ('mixed_float_and_int_column', 'number_series'),
-    ('string_column', 'string_series'),
-    ('mixed_string_and_int_column', 'string_series'),
+    ('int_column', NUMBER_SERIES),
+    ('float_column', NUMBER_SERIES),
+    ('mixed_float_and_int_column', NUMBER_SERIES),
+    ('string_column', STRING_SERIES),
+    ('mixed_string_and_int_column', STRING_SERIES),
 ]
 
 @pytest.mark.parametrize('column_header, filter_type', COLUMN_FILTER_TYPE_TESTS)
@@ -35,6 +35,6 @@ def test_get_mito_type(column_header, filter_type):
 def test_get_mito_type_after_formula():
     mito = create_mito_wrapper(['123'])
     mito.set_formula('=A', 0, 'B', add_column=True)
-    assert 'string_series' == get_mito_type(mito.get_column(0, 'B', False))
+    assert STRING_SERIES == get_mito_type(mito.get_column(0, 'B', False))
     mito.set_formula('=100', 0, 'C', add_column=True)
-    assert 'number_series' == get_mito_type(mito.get_column(0, 'C', False))
\ No newline at end of file
+    assert NUMBER_SERIES == get_mito_type(mito.get_column(0, 'C', False))
\ No newline at end of file
