@@ -4,12 +4,13 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 
+from typing import Any
 import pytest
 
 from mitosheet.errors import MitoError
 from mitosheet.parser import parse_formula, safe_replace, safe_contains
 
-CONSTANT_TEST_CASES = [
+CONSTANT_TEST_CASES: Any = [
     (
         '=100',
         'B',
