@@ -28,7 +28,8 @@ from mitosheet.step_performers import (
     DataframeDeleteStepPerformer,
     DataframeDuplicateStepPerformer,
     DataframeRenameStepPerformer,
-    BulkOldRenameStepPerformer
+    BulkOldRenameStepPerformer, 
+    ExcelImportStepPerformer
 )
 
 def check_step(
@@ -72,7 +73,7 @@ def test_params_static():
 
     check_step(
         DeleteColumnStepPerformer,
-        2,
+        3,
         'delete_column'
     )
 
@@ -161,7 +162,13 @@ def test_params_static():
         'bulk_old_rename'
     )
 
-    assert len(STEP_PERFORMERS) == 16
+    check_step(
+        ExcelImportStepPerformer,
+        1,
+        'excel_import'
+    )
+
+    assert len(STEP_PERFORMERS) == 17
 
 
 def get_fake_param(param_name):
