@@ -8,14 +8,15 @@
 This file contains helpful functions and classes for testing operations.
 """
 
-from mitosheet.column_headers import get_column_header_id, get_column_header_ids
-from typing import List
-from mitosheet.utils import get_new_id
-import pandas as pd
-from mitosheet.transpiler.transpile import transpile
-
-from mitosheet.mito_widget import sheet, MitoWidget
 import json
+from typing import List
+
+import pandas as pd
+from mitosheet.mito_widget import MitoWidget, sheet
+from mitosheet.transpiler.transpile import transpile
+from mitosheet.utils import get_new_id
+from mitosheet.api.get_sheet_data import get_sheet_data
+
 
 class MitoWidgetTestWrapper:
     """
@@ -561,6 +562,24 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    def get_sheet_data_str(self, sheet_index: int, starting_row_index: int=0):
+        """
+        Returns a series object of the given column, or a list if
+        as_list is True. 
+
+        Errors if the column does not exist. 
+        """
+        return get_sheet_data(
+            {
+                'event': 'api_call',
+                'id': get_new_id(),
+                'type': 'get_sheet_data',
+                'sheet_index': sheet_index,
+                'starting_row_index': starting_row_index
+            },
+            self.mito_widget.steps_manager
+        )
+
     def get_formula(self, sheet_index: int, column_header: str):
         """
         Gets the formula for a given column. Returns an empty
@@ -628,4 +647,4 @@ def create_mito_wrapper_dfs(*args):
     data frames.
     """
     mito_widget = sheet(*args)
-    return MitoWidgetTestWrapper(mito_widget)
\ No newline at end of file
+    return MitoWidgetTestWrapper(mito_widget)
