@@ -14,13 +14,13 @@ CHECKOUT_STEP_BY_IDX_UPDATE_PARAMS = [
 ]
 
 def execute_checkout_step_by_idx_update(
-        wsc,
+        steps_manager,
         step_idx
     ):
     """
     Checks out a specific step by index
     """
-    wsc.curr_step_idx = step_idx
+    steps_manager.curr_step_idx = step_idx
 
 CHECKOUT_STEP_BY_IDX_UPDATE = {
     'event_type': CHECKOUT_STEP_BY_IDX_UPDATE_EVENT,
