@@ -5,11 +5,12 @@
 # Distributed under the terms of the Modified BSD License.
 
 
+from typing import List
 from mitosheet.step_performers.import_steps.simple_import import SimpleImportStepPerformer
 
 
 CLEAR_EVENT = 'clear'
-CLEAR_PARAMS = []
+CLEAR_PARAMS: List[str] = []
 
 def execute_clear_update(steps_manager):
     steps_manager.execute_clear()
