@@ -5,10 +5,11 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
+from typing import List
 
 
 REDO_EVENT = 'redo'
-REDO_PARAMS = []
+REDO_PARAMS: List[str] = []
 
 def execute_redo_update(steps_manager):
     steps_manager.execute_redo()
