@@ -4,11 +4,10 @@
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
 
-from copy import copy
-from mitosheet.updates.redo import execute_redo_update
+from typing import List
 
 UNDO_EVENT = 'undo'
-UNDO_PARAMS = []
+UNDO_PARAMS: List[str] = []
 
 def execute_undo_update(steps_manager):
     steps_manager.execute_undo()
