@@ -32,7 +32,7 @@ the other.
 _Any change the user.json format must be met with a version bump._
 """
 from mitosheet.user.schemas import (
-    UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES,
+    UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES, UJ_MITOSHEET_TELEMETRY,
     UJ_USER_JSON_VERSION, UJ_MITOSHEET_LAST_FIFTY_USAGES
 )
 from mitosheet.user.schemas import USER_JSON_DEFAULT, USER_JSON_VERSION_1
@@ -96,6 +96,17 @@ def upgrade_final_user_json_version_1_to_2(final_user_json_version_1):
 
     return final_user_json_version_1
 
+def upgrade_user_json_version_2_to_3(user_json_version_2):
+    """
+    Just adds the user json telemtry field
+    """
+    # First, bump the version number
+    user_json_version_2[UJ_USER_JSON_VERSION] = 3
+
+    # Then, set new field
+    user_json_version_2[UJ_MITOSHEET_TELEMETRY] = True
+    return user_json_version_2
+
 def try_upgrade_user_json_to_current_version():
     user_json_object = get_user_json_object()
 
@@ -110,6 +121,8 @@ def try_upgrade_user_json_to_current_version():
     # most up-to-date version
     if user_json_object[UJ_USER_JSON_VERSION] == 1:
         user_json_object = upgrade_final_user_json_version_1_to_2(user_json_object)
+    if user_json_object[UJ_USER_JSON_VERSION] == 2:
+        user_json_object = upgrade_user_json_version_2_to_3(user_json_object)
 
     set_user_json_object(user_json_object)
 
