@@ -65,27 +65,3 @@ def should_upgrade_mitosheet():
     mitosheet_last_upgraded_date = datetime.strptime(get_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE), '%Y-%m-%d')
     return (datetime.now() - mitosheet_last_upgraded_date).days > 21
 
-
-def should_display_feedback():
-    """
-    The user gives an initial piece of feedback when they first sign up
-    for Mito. Thus, all users have 1 piece of feedback. 
-    
-    We then expect them to give feedback on days: 2, 7, 20, 35, 49 
-    of using the tool. We thus check the number of feedbacks they have
-    given to that point.
-
-    NOTE: as the user can submit feedback manually, this might be annoying
-    for some users, as they might get prompted after they submit feedback.
-    However, as we have never seen a user do this, we don't worry about it
-    for now.
-    """
-    num_feedbacks = len(get_user_field(UJ_FEEDBACKS))
-    num_days = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
-
-    return (num_feedbacks <= 1 and num_days == 2) or \
-        (num_feedbacks == 2 and num_days == 7) or \
-        (num_feedbacks <= 3 and num_days == 20) or \
-        (num_feedbacks <= 4 and num_days == 35) or \
-        (num_feedbacks <= 5 and num_days == 49)
-
