@@ -36,6 +36,9 @@ def get_first_unused_dataframe_name(existing_df_names: List[str], new_dataframe_
         if new_name not in existing_df_names:
             return new_name
 
+    # NOTE: We should never reach this, as the above loop will
+    # find a dataframe name that is taken
+    return new_dataframe_name
 
 def get_valid_dataframe_name(existing_df_names: List[str], original_dataframe_name: str) -> str:
     """
@@ -59,7 +62,7 @@ def get_valid_dataframe_names(existing_df_names: List[str], original_df_names: L
     names for dataframes, that do not overlap with the existing dataframe names.
     """
 
-    final_names = []
+    final_names: List[str] = []
 
     for original_df_name in original_df_names:
         new_names_final = get_valid_dataframe_name(
@@ -89,7 +92,10 @@ def dfs_to_json(
             column_filters_array[sheet_index],
             column_mito_types_array[sheet_index],
             column_ids.column_header_to_column_id[sheet_index],
-            column_ids.column_id_to_column_header[sheet_index]
+            # NOTE: since we now lazy-load, we simply don't include any of the actual
+            # column data in the sheet data array that is passed to the frontend.
+            # Instead, this data is now loading in Endo.tsx, in the loadSheetData function
+            max_length=0
         ) 
         for sheet_index, df in enumerate(dfs)
     ])
@@ -103,8 +109,8 @@ def df_to_json_dumpsable(
         column_filters: Dict[str, Any],
         column_mito_types: Dict[str, str],
         column_headers_to_column_ids: Dict[Any, str],
-        column_ids_to_column_headers: Dict[str, Any],
-        length_restriction=True # Used if we want to only return the first 2k rows of the dataframe
+        max_length=2000, # How many items you want to display
+        starting_index=0
     ):
     """
     Returns a dataframe represented in a way that can be turned into a 
@@ -132,11 +138,14 @@ def df_to_json_dumpsable(
 
     (num_rows, num_columns) = df.shape 
 
-    # First, if the length_restriction is True, we get the head, and then 
+    if starting_index > 0 and starting_index < num_rows:
+        df = df.iloc[starting_index:]
+
+    # First, if the max_length is set, we get the head, and then 
     # we make a copy (as we modify the df below)
     # NOTE: we get the head first for efficiency reasons.
-    if length_restriction:
-        df = df.head(n=2000).copy(deep=True) # we only show the first 2k rows!
+    if max_length is not None:
+        df = df.head(n=max_length).copy(deep=True) # we only show the first max_length rows!
     
     # Second, we figure out which of the columns contain dates, and we
     # convert them to string columns (for formatting reasons).
